/**
 * CFilterSelect - 筛选项目，单项选择
 * @author Tevin
 */

<template>
    <view
        class="c-filter-select"
        :class="'type-'+place"
    >
        <view
            class="label"
            v-if="place==='item'"
        >{{label}}</view>
        <picker
            mode="selector"
            range-key="name"
            :range="options2"
            :value="current"
            @change="evt => handleChange(evt.detail.value)"
        >
            <view class="content">
                <view
                    class="label"
                    v-if="place==='bar'"
                >{{label}}</view>
                <view :class="selected?'filled':'empty'">
                    {{selected ? options2[current].name : ('请选择' + label)}}
                </view>
                <view class="at-icon at-icon-chevron-down" />
            </view>
        </picker>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import './cFilterSelect.scss';

export default {
    name: 'CFilterSelect',
    props: {
        // 位置类型，bar、item
        place: String,
        // 项名称
        label: String,
        // 项键名
        name: String,
        // 选项
        options: {
            type: Array,
            default: () => [],
        },
        // 是否额外显示【取消选择】的项
        cancelable: {
            type: Boolean,
            default: true,
        },
        // 项值
        value: [Number, String],
        // 变化回调
        onChange: Function,
    },
    data() {
        return {};
    },
    computed: {
        options2() {
            if (this.cancelable) {
                return [{ name: '- 取消选择 -' }, ...this.options];
            } else {
                return [...this.options];
            }
        },
        current() {
            for (let i = 0, item; (item = this.options2[i]); i++) {
                if (this.value === item.value) {
                    return i;
                }
            }
            return 0;
        },
        selected() {
            if (typeof this.value === 'undefined') {
                return false;
            }
            for (let item of this.options) {
                if (this.value === item.value) {
                    return true;
                }
            }
            return false;
        },
    },
    methods: {
        handleChange(index) {
            const selectIndex = Number(index);
            const selectItem = this.options2[selectIndex];
            const changed = {
                place: this.place,
                name: this.name,
                value: undefined,
            };
            if (selectItem.value || selectItem.value === 0) {
                changed.value = selectItem.value;
            } else if (selectItem.id) {
                changed.value = selectItem.id;
            }
            // 显示取消项时
            if (this.cancelable) {
                if (selectIndex > 0) {
                    this.onChange(changed);
                } else {
                    changed.value = undefined;
                    this.onChange(changed);
                }
            }
            // 正常显示时
            else {
                this.onChange(changed);
            }
        },
    },
};
</script>